@@ -1,12 +1,12 @@
-use std::ops::Add;
-use std::ops::AddAssign;
-use std::ops::Div;
-use std::ops::DivAssign;
-use std::ops::Mul;
-use std::ops::MulAssign;
-use std::ops::Rem;
-use std::ops::Sub;
-use std::ops::SubAssign;
+use ::std::ops::Add;
+use ::std::ops::AddAssign;
+use ::std::ops::Div;
+use ::std::ops::DivAssign;
+use ::std::ops::Mul;
+use ::std::ops::MulAssign;
+use ::std::ops::Rem;
+use ::std::ops::Sub;
+use ::std::ops::SubAssign;
 
 use crate::num::Num;
 
